// button-cell-renderer.component.ts
import { Component } from '@angular/core';
import { ICellRendererAngularComp } from 'ag-grid-angular';
import { ICellRendererParams } from 'ag-grid-community';

export interface ButtonCellRendererParams extends ICellRendererParams {
  label: string;
  type: 'default' | 'reminder';
}

@Component({
  selector: 'app-button-cell-renderer',
  template: `<app-button
    size="small"
    [disabled]="disabled"
    [label]="label"
    [variant]="'secondary'"
    [style]="'display: inline-block;max-width: 100%;'"
  />`,
  styles: [
    `
      ::ng-deep button {
        max-width: 100%;
        min-width: 60px;
      }
    `,
  ],
})
export class ButtonCellRendererComponent implements ICellRendererAngularComp {
  public disabled = false;
  public label = '';

  agInit(params: ButtonCellRendererParams): void {
    if (params.type === 'reminder') {
      this.disabled = this.shouldDisableReminder(params);
    }
    this.label = params.label;
  }

  refresh(): boolean {
    return false;
  }

  public shouldDisableReminder(params: ButtonCellRendererParams): boolean {
    return !params.data.isOutdated || params.context.gridId === 'toClaim';
  }
}
